( cd usr/lib ; rm -rf libcrypto.so.0 )
( cd usr/lib ; ln -sf libcrypto.so.0.9.6 libcrypto.so.0 )
( cd usr/lib ; rm -rf libcrypto.so )
( cd usr/lib ; ln -sf libcrypto.so.0 libcrypto.so )
( cd usr/lib ; rm -rf libssl.so.0 )
( cd usr/lib ; ln -sf libssl.so.0.9.6 libssl.so.0 )
( cd usr/lib ; rm -rf libssl.so )
( cd usr/lib ; ln -sf libssl.so.0 libssl.so )
